@@ -73,6 +73,11 @@ T = TypeVar("T")
 E = TypeVar("E", bound=Exception)
 D = TypeVar("D", bound=Document)
 
+if sys.version_info[:2] >= (3, 7):  # pragma: no cover
+    PathLike = Union[str, bytes, os.PathLike]
+else:  # pragma: no cover
+    PathLike = Union[str, os.PathLike]
+
 ConfigContent = Union["Section", "Comment", "Space"]
 
 
@@ -220,15 +225,15 @@ class Parser:
         return ReadOnlyMapping(self._get_args())
 
     @overload
-    def read(self, filename: str, encoding: Optional[str] = None) -> Document:
+    def read(self, filename: PathLike, encoding: Optional[str] = None) -> Document:
         ...
 
     @overload
-    def read(self, filename: str, encoding: str, into: D) -> D:
+    def read(self, filename: PathLike, encoding: str, into: D) -> D:
         ...
 
     @overload
-    def read(self, filename: str, *, into: D, encoding: Optional[str] = None) -> D:
+    def read(self, filename: PathLike, *, into: D, encoding: Optional[str] = None) -> D:
         ...
 
     def read(self, filename, encoding=None, into=None):
@@ -241,7 +246,7 @@ class Parser:
         """
         document = Document() if into is None else into
         with open(filename, encoding=encoding) as fp:
-            self._read(fp, filename, document)
+            self._read(fp, str(filename), document)
         self._filename = os.path.abspath(filename)
         return document
 
@@ -337,7 +342,7 @@ class Parser:
         new_section.raw_comment = raw_comment
         self._document.append(new_section)
 
-    def _add_option(self, key: str, vi: str, value: str, line: str):
+    def _add_option(self, key: str, vi: str, value: Optional[str], line: str):
         if not isinstance(self._last_block, Section):  # pragma: no cover
             msg = f"{self._last_block!r} should be Section"
             raise InconsistentStateError(msg, self._fpname, self._lineno, line)
@@ -407,7 +412,7 @@ class Parser:
         """
         self._document = into
         elements_added: set = set()
-        cursect: Optional[Dict[str, List[str]]] = None  # None, or a dictionary
+        cursect: Optional[Dict[str, List[str]]] = None  # None or dict
         sectname: Optional[str] = None
         optname: Optional[str] = None
         lineno = 0
@@ -511,7 +516,7 @@ class Parser:
                             cursect[optname] = [optval]
                         else:
                             # valueless option handling
-                            cursect[optname] = None
+                            cursect[optname] = []  # None in Configparser
                         self._add_option(optname, vi, optval, line)  # HOOK
                     # handle indented comment
                     elif (
